==> varsnap-0.4.0.tgz: package/test/core.js <==
const expect = require('chai').expect;
const sinon = require('sinon');

const varsnap = require('../varsnap/core');
const configTools = require('./config_tools');

function example(x, y) {
  return x * y;
}

describe('Util', () => {
  describe('getConfig', () => {
    it('can read from env vars', () => {
      const config = varsnap.Util.getConfig(configTools.producerConfig(), 'env');
      expect(config).to.equal('production');
    });
    it('will lowercase configs', () => {
      const configs = {
        'env': 'TEST'
      };
      const config = varsnap.Util.getConfig(configs, 'env');
      expect(config).to.equal('test');
    });
    it('will work with non-string configs', () => {
      const configs = {
        'varsnap': true,
      };
      const config = varsnap.Util.getConfig(configs, 'varsnap');
      expect(config).to.equal('true');
    });
    it('will default to empty string if there are no configs', () => {
      const config = varsnap.Util.getConfig(undefined, 'env');
      expect(config).to.equal('');
    });
    it('will default to empty string if config is not defined', () => {
      const configs = {
        'varsnap': true,
      };
      const config = varsnap.Util.getConfig(configs, 'env');
      expect(config).to.equal('');
    });
  });

  describe('getSignature', () => {
    it('returns a valid signature', () => {
      const signature = varsnap.Util.getSignature(varsnap.Util.getConfig);
      expect(signature).to.include('javascript');
      expect(signature).to.include(varsnap.version);
      expect(signature).to.include('getConfig');
    });
  });
});

describe('Producer', () => {
  beforeEach(() => {
    this.producer = new varsnap.Producer(example, configTools.producerConfig());
  });
  describe('isEnabled', () => {
    it('will return false if varsnap is not enabled', () => {
      this.producer.config[varsnap.configKeys.varsnap] = 'false';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return false if env is not production', () => {
      this.producer.config[varsnap.configKeys.env] = 'development';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return false if producer token is not set', () => {
      this.producer.config[varsnap.configKeys.producerToken] = '';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return true if all configs are correct', () => {
      expect(this.producer.isEnabled()).to.be.true;
    });
  });
  describe('serialize', () => {
    it('can serialize data', () => {
      expect(varsnap.Producer.serialize(5)).to.equal('5');
      expect(varsnap.Producer.serialize({'1':[2]})).to.equal('{"1":[2]}');
    });
  });
  describe('produce', () => {
    beforeEach(() => {
      configTools.setProducerConfig();
      this.ajax = sinon.stub(varsnap.Util, 'ajax');
    });
    afterEach(() => {
      this.ajax.restore();
    });
    it('will send data', () => {
      this.ajax.resolves('asdf');
      this.producer.produce([2, 3], 6);
      sinon.assert.called(this.ajax);
    });
  });
});

describe('Consumer', () => {
  beforeEach(() => {
    this.consumer = new varsnap.Consumer(example, configTools.consumerConfig());
  });
  describe('isEnabled', () => {
    it('will return false if varsnap is not enabled', () => {
      this.consumer.config[varsnap.configKeys.varsnap] ='false';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return false if env is not development', () => {
      this.consumer.config[varsnap.configKeys.env] = 'production';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return false if consumer token is not set', () => {
      this.consumer.config[varsnap.configKeys.consumerToken] = '';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return true if all configs are correct', () => {
      expect(this.consumer.isEnabled()).to.be.true;
    });
  });
  describe('deserialize', () => {
    it('can deserialize data', () => {
      expect(varsnap.Consumer.deserialize('5')).to.equal(5);
      expect(varsnap.Consumer.deserialize('{"1":[2]}')).to.deep.equal({'1':[2]});
    });
  });
  describe('consume', () => {
    beforeEach(() => {
      configTools.setConsumerConfig();
      this.clock = sinon.useFakeTimers();
      this.ajax = sinon.stub(varsnap.Util, 'ajax');
    });
    afterEach(() => {
      this.clock.restore();
      this.ajax.restore();
    });
    it('will not run if the consumer is not enabled', () => {
      this.consumer.config[varsnap.configKeys.env] = 'production';
      this.consumer.consume();
      this.clock.tick(1001);
      sinon.assert.callCount(this.ajax, 0);
    });
    it('will make an ajax request and report it', () => {
      this.consumer.consume();
      const data = {
        'id': 'abcd',
        'inputs': '[2, 3]',
        'prod_outputs': '4',
      };
      this.ajax.resolves(data);
      this.clock.tick(1001);
      sinon.assert.called(this.ajax);
    });
  });
});

describe('varsnap', () => {
  beforeEach(() => {
    configTools.setProducerConfig();
    varsnap.Util.resetConsumers();
    varsnap.Util.resetProducers();
  });
  it('creates a consumer and producer', () => {
    const wrapped = varsnap.varsnap(example);
    expect(wrapped.producer.targetFunc).to.equal(example);
    expect(wrapped.producer.config).to.equal(varsnap.varsnap.config);
    expect(wrapped.consumer.targetFunc).to.equal(example);
    expect(wrapped.consumer.config).to.equal(varsnap.varsnap.config);
  });
  it('wraps a function', () => {
    const wrapped = varsnap.varsnap(example);
    expect(wrapped(2, 4)).to.equal(8);
  });
  it('saves consumers and producers', () => {
    expect(varsnap.Util.getConsumers().length).to.equal(0);
    expect(varsnap.Util.getConsumers().length).to.equal(0);
    varsnap.varsnap(example);
    expect(varsnap.Util.getConsumers().length).to.equal(1);
    expect(varsnap.Util.getConsumers().length).to.equal(1);
  });
});

describe('version', () => {
  it('has a version', () => {
    expect(varsnap.version).to.be;
  });
});

==> varsnap-0.4.3.tgz: package/test/core.js <==
const expect = require('chai').expect;
const sinon = require('sinon');

const varsnap = require('../varsnap/core');
const configTools = require('./config_tools');

function example(x, y) {
  return x * y;
}

describe('Util', () => {
  describe('getConfig', () => {
    it('can read from env vars', () => {
      const config = varsnap.Util.getConfig(configTools.producerConfig(), 'env');
      expect(config).to.equal('production');
    });
    it('will lowercase configs', () => {
      const configs = {
        'env': 'TEST'
      };
      const config = varsnap.Util.getConfig(configs, 'env');
      expect(config).to.equal('test');
    });
    it('will work with non-string configs', () => {
      const configs = {
        'varsnap': true,
      };
      const config = varsnap.Util.getConfig(configs, 'varsnap');
      expect(config).to.equal('true');
    });
    it('will default to empty string if there are no configs', () => {
      const config = varsnap.Util.getConfig(undefined, 'env');
      expect(config).to.equal('');
    });
    it('will default to empty string if config is not defined', () => {
      const configs = {
        'varsnap': true,
      };
      const config = varsnap.Util.getConfig(configs, 'env');
      expect(config).to.equal('');
    });
  });

  describe('getSignature', () => {
    it('returns a valid signature', () => {
      const signature = varsnap.Util.getSignature(varsnap.Util.getConfig);
      expect(signature).to.include('javascript');
      expect(signature).to.include(varsnap.version);
      expect(signature).to.include('getConfig');
    });
  });
});

describe('Producer', () => {
  beforeEach(() => {
    this.producer = new varsnap.Producer(example, configTools.producerConfig());
  });
  describe('isEnabled', () => {
    it('will return false if varsnap is not enabled', () => {
      this.producer.config[varsnap.configKeys.varsnap] = 'false';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return false if env is not production', () => {
      this.producer.config[varsnap.configKeys.env] = 'development';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return false if producer token is not set', () => {
      this.producer.config[varsnap.configKeys.producerToken] = '';
      expect(this.producer.isEnabled()).to.be.false;
    });
    it('will return true if all configs are correct', () => {
      expect(this.producer.isEnabled()).to.be.true;
    });
  });
  describe('serialize', () => {
    it('can serialize data', () => {
      expect(varsnap.Producer.serialize(5)).to.equal('5');
      expect(varsnap.Producer.serialize({'1':[2]})).to.equal('{"1":[2]}');
    });
  });
  describe('produce', () => {
    beforeEach(() => {
      configTools.setProducerConfig();
      this.ajax = sinon.stub(varsnap.Util, 'ajax');
    });
    afterEach(() => {
      this.ajax.restore();
    });
    it('will send data', () => {
      this.ajax.resolves('asdf');
      this.producer.produce([2, 3], 6);
      sinon.assert.called(this.ajax);
    });
  });
});

describe('Consumer', () => {
  beforeEach(() => {
    this.consumer = new varsnap.Consumer(example, configTools.consumerConfig());
  });
  describe('isEnabled', () => {
    it('will return false if varsnap is not enabled', () => {
      this.consumer.config[varsnap.configKeys.varsnap] ='false';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return false if env is not development', () => {
      this.consumer.config[varsnap.configKeys.env] = 'production';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return false if consumer token is not set', () => {
      this.consumer.config[varsnap.configKeys.consumerToken] = '';
      expect(this.consumer.isEnabled()).to.be.false;
    });
    it('will return true if all configs are correct', () => {
      expect(this.consumer.isEnabled()).to.be.true;
    });
  });
  describe('deserialize', () => {
    it('can deserialize data', () => {
      expect(varsnap.Consumer.deserialize('5')).to.equal(5);
      expect(varsnap.Consumer.deserialize('{"1":[2]}')).to.deep.equal({'1':[2]});
    });
  });
  describe('consumeOnce', () => {
    beforeEach(() => {
      configTools.setConsumerConfig();
      this.ajax = sinon.stub(varsnap.Util, 'ajax');
    });
    afterEach(() => {
      this.ajax.restore();
    });
    it('will not run if the consumer is not enabled', () => {
      this.consumer.config[varsnap.configKeys.env] = 'production';
      this.consumer.consumeOnce();
      sinon.assert.callCount(this.ajax, 0);
    });
    it('will make an ajax request and report it', () => {
      const data = {
        'id': 'abcd',
        'inputs': '[2, 3]',
        'prod_outputs': '4',
      };
      this.ajax.resolves(data);
      this.consumer.consumeOnce();
      sinon.assert.called(this.ajax);
    });
  });
});

describe('varsnap', () => {
  beforeEach(() => {
    configTools.setProducerConfig();
    varsnap.Util.resetConsumers();
    varsnap.Util.resetProducers();
  });
  it('creates a consumer and producer', () => {
    const wrapped = varsnap.varsnap(example);
    expect(wrapped.producer.targetFunc).to.equal(example);
    expect(wrapped.producer.config).to.equal(varsnap.varsnap.config);
    expect(wrapped.consumer.targetFunc).to.equal(example);
    expect(wrapped.consumer.config).to.equal(varsnap.varsnap.config);
  });
  it('wraps a function', () => {
    const wrapped = varsnap.varsnap(example);
    expect(wrapped(2, 4)).to.equal(8);
  });
  it('saves consumers and producers', () => {
    expect(varsnap.Util.getConsumers().length).to.equal(0);
    expect(varsnap.Util.getConsumers().length).to.equal(0);
    varsnap.varsnap(example);
    expect(varsnap.Util.getConsumers().length).to.equal(1);
    expect(varsnap.Util.getConsumers().length).to.equal(1);
  });
});

describe('version', () => {
  it('has a version', () => {
    expect(varsnap.version).to.be;
  });
});
